@@ -29,18 +29,16 @@
 #include <pybind11/buffer_info.h>
 
 #include "qpdf_pagelist.h"
-#include "qpdf_inputsource.h"
-#include "mmap_inputsource.h"
+#include "qpdf_inputsource-inl.h"
+#include "mmap_inputsource-inl.h"
 #include "pipeline.h"
 #include "utils.h"
 #include "gsl.h"
 
-
 extern bool MMAP_DEFAULT;
 
 enum access_mode_e { access_default, access_stream, access_mmap, access_mmap_only };
 
-
 void check_stream_is_usable(py::object stream)
 {
     auto TextIOBase = py::module_::import("io").attr("TextIOBase");
@@ -50,22 +48,20 @@ void check_stream_is_usable(py::object stream)
     }
 }
 
-void qpdf_basic_settings(QPDF& q)
+void qpdf_basic_settings(QPDF &q)
 {
     q.setSuppressWarnings(true);
     q.setImmediateCopyFrom(true);
 }
 
-std::shared_ptr<QPDF>
-open_pdf(
-    py::object filename_or_stream,
+std::shared_ptr<QPDF> open_pdf(py::object filename_or_stream,
     std::string password,
-    bool hex_password=false,
-    bool ignore_xref_streams=false,
-    bool suppress_warnings=true,
-    bool attempt_recovery=true,
-    bool inherit_page_attributes=true,
-    access_mode_e access_mode=access_mode_e::access_default)
+    bool hex_password            = false,
+    bool ignore_xref_streams     = false,
+    bool suppress_warnings       = true,
+    bool attempt_recovery        = true,
+    bool inherit_page_attributes = true,
+    access_mode_e access_mode    = access_mode_e::access_default)
 {
     auto q = std::make_shared<QPDF>();
 
@@ -79,20 +75,21 @@ open_pdf(
     bool closing_stream;
     std::string description;
 
-    if (py::hasattr(filename_or_stream, "read") && py::hasattr(filename_or_stream, "seek")) {
+    if (py::hasattr(filename_or_stream, "read") &&
+        py::hasattr(filename_or_stream, "seek")) {
         // Python code gave us an object with a stream interface
         stream = filename_or_stream;
         check_stream_is_usable(stream);
         closing_stream = false;
-        description = py::repr(stream);
+        description    = py::repr(stream);
     } else {
         if (py::isinstance<py::int_>(filename_or_stream))
             throw py::type_error("expected str, bytes or os.PathLike object");
-        auto filename = fspath(filename_or_stream);
-        auto io_open = py::module_::import("io").attr("open");
-        stream = io_open(filename, "rb");
+        auto filename  = fspath(filename_or_stream);
+        auto io_open   = py::module_::import("io").attr("open");
+        stream         = io_open(filename, "rb");
         closing_stream = true;
-        description = py::str(filename);
+        description    = py::str(filename);
     }
 
     bool success = false;
@@ -102,9 +99,8 @@ open_pdf(
     if (access_mode == access_mmap || access_mode == access_mmap_only) {
         try {
             py::gil_scoped_release release;
-            auto mmap_input_source = std::make_unique<MmapInputSource>(
-                stream, description, closing_stream
-            );
+            auto mmap_input_source =
+                std::make_unique<MmapInputSource>(stream, description, closing_stream);
             auto input_source = PointerHolder<InputSource>(mmap_input_source.release());
             q->processInputSource(input_source, password.c_str());
             success = true;
@@ -122,8 +118,7 @@ open_pdf(
     if (!success && access_mode == access_stream) {
         py::gil_scoped_release release;
         auto stream_input_source = std::make_unique<PythonStreamInputSource>(
-            stream, description, closing_stream
-        );
+            stream, description, closing_stream);
         auto input_source = PointerHolder<InputSource>(stream_input_source.release());
         q->processInputSource(input_source, password.c_str());
         success = true;
@@ -143,10 +138,7 @@ open_pdf(
 
 class PikeProgressReporter : public QPDFWriter::ProgressReporter {
 public:
-    PikeProgressReporter(py::function callback)
-    {
-        this->callback = callback;
-    }
+    PikeProgressReporter(py::function callback) { this->callback = callback; }
 
     virtual ~PikeProgressReporter() = default;
 
@@ -155,28 +147,25 @@ public:
         py::gil_scoped_acquire acquire;
         this->callback(percent);
     }
+
 private:
     py::function callback;
 };
 
-
 void update_xmp_pdfversion(QPDF &q, std::string version)
 {
-    auto impl = py::module_::import("pikepdf._cpphelpers").attr("update_xmp_pdfversion");
+    auto impl =
+        py::module_::import("pikepdf._cpphelpers").attr("update_xmp_pdfversion");
     auto pypdf = py::cast(q);
     impl(pypdf, version);
 }
 
-
-void setup_encryption(
-    QPDFWriter &w,
-    py::object encryption
-)
+void setup_encryption(QPDFWriter &w, py::object encryption)
 {
     std::string owner;
     std::string user;
 
-    bool aes = true;
+    bool aes      = true;
     bool metadata = true;
     std::map<std::string, bool> allow;
     int encryption_level = 6;
@@ -196,32 +185,36 @@ void setup_encryption(
 
     if (encryption.contains("owner")) {
         if (encryption_level <= 4) {
-            auto success = QUtil::utf8_to_pdf_doc(encryption["owner"].cast<std::string>(), owner);
+            auto success =
+                QUtil::utf8_to_pdf_doc(encryption["owner"].cast<std::string>(), owner);
             if (!success)
-                throw py::value_error("Encryption level is R3/R4 and password is not encodable as PDFDocEncoding");
+                throw py::value_error("Encryption level is R3/R4 and password is not "
+                                      "encodable as PDFDocEncoding");
         } else {
             owner = encryption["owner"].cast<std::string>();
         }
     }
     if (encryption.contains("user")) {
         if (encryption_level <= 4) {
-            auto success = QUtil::utf8_to_pdf_doc(encryption["user"].cast<std::string>(), user);
+            auto success =
+                QUtil::utf8_to_pdf_doc(encryption["user"].cast<std::string>(), user);
             if (!success)
-                throw py::value_error("Encryption level is R3/R4 and password is not encodable as PDFDocEncoding");
+                throw py::value_error("Encryption level is R3/R4 and password is not "
+                                      "encodable as PDFDocEncoding");
         } else {
             user = encryption["user"].cast<std::string>();
         }
     }
     if (encryption.contains("allow")) {
-        auto pyallow = encryption["allow"];
-        allow["accessibility"] = pyallow.attr("accessibility").cast<bool>();
-        allow["extract"] = pyallow.attr("extract").cast<bool>();
-        allow["modify_assembly"] = pyallow.attr("modify_assembly").cast<bool>();
+        auto pyallow               = encryption["allow"];
+        allow["accessibility"]     = pyallow.attr("accessibility").cast<bool>();
+        allow["extract"]           = pyallow.attr("extract").cast<bool>();
+        allow["modify_assembly"]   = pyallow.attr("modify_assembly").cast<bool>();
         allow["modify_annotation"] = pyallow.attr("modify_annotation").cast<bool>();
-        allow["modify_form"] = pyallow.attr("modify_form").cast<bool>();
-        allow["modify_other"] = pyallow.attr("modify_other").cast<bool>();
-        allow["print_lowres"] = pyallow.attr("print_lowres").cast<bool>();
-        allow["print_highres"] = pyallow.attr("print_highres").cast<bool>();
+        allow["modify_form"]       = pyallow.attr("modify_form").cast<bool>();
+        allow["modify_other"]      = pyallow.attr("modify_other").cast<bool>();
+        allow["print_lowres"]      = pyallow.attr("print_lowres").cast<bool>();
+        allow["print_highres"]     = pyallow.attr("print_highres").cast<bool>();
     }
     if (encryption.contains("aes")) {
         if (py::isinstance<py::bool_>(encryption["aes"]))
@@ -250,7 +243,8 @@ void setup_encryption(
         throw py::value_error("When R = 6, AES encryption must be enabled");
     }
     if (metadata && !aes) {
-        throw py::value_error("Cannot encrypt metadata unless AES encryption is enabled");
+        throw py::value_error(
+            "Cannot encrypt metadata unless AES encryption is enabled");
     }
 
     qpdf_r3_print_e print;
@@ -262,8 +256,8 @@ void setup_encryption(
         print = qpdf_r3p_none;
 
     if (encryption_level == 6) {
-        w.setR6EncryptionParameters(
-            user.c_str(), owner.c_str(),
+        w.setR6EncryptionParameters(user.c_str(),
+            owner.c_str(),
             allow["accessibility"],
             allow["extract"],
             allow["modify_assembly"],
@@ -271,12 +265,11 @@ void setup_encryption(
             allow["modify_form"],
             allow["modify_other"],
             print,
-            metadata
-        );
+            metadata);
     } else if (encryption_level == 5) {
         // TODO WARNING
-        w.setR5EncryptionParameters(
-            user.c_str(), owner.c_str(),
+        w.setR5EncryptionParameters(user.c_str(),
+            owner.c_str(),
             allow["accessibility"],
             allow["extract"],
             allow["modify_assembly"],
@@ -284,11 +277,10 @@ void setup_encryption(
             allow["modify_form"],
             allow["modify_other"],
             print,
-            metadata
-        );
+            metadata);
     } else if (encryption_level == 4) {
-        w.setR4EncryptionParameters(
-            user.c_str(), owner.c_str(),
+        w.setR4EncryptionParameters(user.c_str(),
+            owner.c_str(),
             allow["accessibility"],
             allow["extract"],
             allow["modify_assembly"],
@@ -297,70 +289,65 @@ void setup_encryption(
             allow["modify_other"],
             print,
             metadata,
-            aes
-        );
+            aes);
     } else if (encryption_level == 3) {
-        w.setR3EncryptionParameters(
-            user.c_str(), owner.c_str(),
+        w.setR3EncryptionParameters(user.c_str(),
+            owner.c_str(),
             allow["accessibility"],
             allow["extract"],
             allow["modify_assembly"],
             allow["modify_annotation"],
             allow["modify_form"],
             allow["modify_other"],
-            print
-        );
+            print);
     } else if (encryption_level == 2) {
-        w.setR2EncryptionParameters(
-            user.c_str(), owner.c_str(),
+        w.setR2EncryptionParameters(user.c_str(),
+            owner.c_str(),
             (print != qpdf_r3p_none),
             allow["modify_assembly"],
             allow["extract"],
-            allow["modify_annotation"]
-        );
+            allow["modify_annotation"]);
     }
 }
 
-
 typedef std::pair<std::string, int> pdf_version_extension;
 
 pdf_version_extension get_version_extension(py::object ver_ext)
 {
     std::string version = "";
-    int extension = 0;
+    int extension       = 0;
     try {
-        version = ver_ext.cast<std::string>();
+        version   = ver_ext.cast<std::string>();
         extension = 0;
-    } catch (const py::cast_error&) {
+    } catch (const py::cast_error &) {
         try {
             auto version_ext = ver_ext.cast<pdf_version_extension>();
-            version = version_ext.first;
-            extension = version_ext.second;
-        } catch (const py::cast_error&) {
+            version          = version_ext.first;
+            extension        = version_ext.second;
+        } catch (const py::cast_error &) {
             throw py::type_error("PDF version must be a tuple: (str, int)");
         }
     }
     return pdf_version_extension(version, extension);
 }
 
-void save_pdf(
-    QPDF& q,
+void save_pdf(QPDF &q,
     py::object filename_or_stream,
-    bool static_id=false,
-    bool preserve_pdfa=true,
-    py::object min_version=py::none(),
-    py::object force_version=py::none(),
-    bool fix_metadata_version=true,
-    bool compress_streams=true,
-    py::object stream_decode_level=py::none(),
-    qpdf_object_stream_e object_stream_mode=qpdf_o_preserve,
-    bool normalize_content=false,
-    bool linearize=false,
-    bool qdf=false,
-    py::object progress=py::none(),
-    py::object encryption=py::none(),
-    bool samefile_check=true,
-    bool recompress_flate=false)
+    bool static_id                          = false,
+    bool preserve_pdfa                      = true,
+    py::object min_version                  = py::none(),
+    py::object force_version                = py::none(),
+    bool fix_metadata_version               = true,
+    bool compress_streams                   = true,
+    py::object stream_decode_level          = py::none(),
+    qpdf_object_stream_e object_stream_mode = qpdf_o_preserve,
+    bool normalize_content                  = false,
+    bool linearize                          = false,
+    bool qdf                                = false,
+    py::object progress                     = py::none(),
+    py::object encryption                   = py::none(),
+    bool samefile_check                     = true,
+    bool recompress_flate                   = false)
 {
     std::string description;
     QPDFWriter w(q);
@@ -385,12 +372,13 @@ void save_pdf(
 
     py::object stream;
     bool should_close_stream = false;
-    auto close_stream = gsl::finally([&stream, &should_close_stream] {
+    auto close_stream        = gsl::finally([&stream, &should_close_stream] {
         if (should_close_stream && !stream.is_none() && py::hasattr(stream, "close"))
             stream.attr("close")();
     });
 
-    if (py::hasattr(filename_or_stream, "write") && py::hasattr(filename_or_stream, "seek")) {
+    if (py::hasattr(filename_or_stream, "write") &&
+        py::hasattr(filename_or_stream, "seek")) {
         // Python code gave us an object with a stream interface
         stream = filename_or_stream;
         check_stream_is_usable(stream);
@@ -402,15 +390,14 @@ void save_pdf(
         if (samefile_check) {
             auto input_filename = q.getFilename();
 
-            py::object ospath = py::module_::import("os").attr("path");
+            py::object ospath   = py::module_::import("os").attr("path");
             py::object samefile = ospath.attr("samefile");
             try {
                 if (samefile(output_filename, input_filename).cast<bool>()) {
                     throw py::value_error(
                         "Cannot overwrite input file. Open the file with "
                         "pikepdf.open(..., allow_overwriting_input=True) to "
-                        "allow overwriting the input file."
-                    );
+                        "allow overwriting the input file.");
                 }
             } catch (const py::error_already_set &e) {
                 // We expect FileNotFoundError if filename refers to a file that does
@@ -422,7 +409,7 @@ void save_pdf(
         }
         stream = py::module_::import("io").attr("open")(output_filename, "wb");
         should_close_stream = true;
-        description = py::str(output_filename);
+        description         = py::str(output_filename);
     }
 
     // We must set up the output pipeline before we configure encryption
@@ -430,14 +417,14 @@ void save_pdf(
     w.setOutputPipeline(&output_pipe);
 
     if (encryption.is(py::bool_(true)) && !q.isEncrypted()) {
-        throw py::value_error("can't perserve encryption parameters on a file with no encryption");
+        throw py::value_error(
+            "can't perserve encryption parameters on a file with no encryption");
     }
 
-    if (
-        (encryption.is(py::bool_(true)) || py::isinstance<py::dict>(encryption))
-            && (normalize_content || !stream_decode_level.is_none())
-    ) {
-        throw py::value_error("cannot save with encryption and normalize_content or stream_decode_level");
+    if ((encryption.is(py::bool_(true)) || py::isinstance<py::dict>(encryption)) &&
+        (normalize_content || !stream_decode_level.is_none())) {
+        throw py::value_error(
+            "cannot save with encryption and normalize_content or stream_decode_level");
     }
 
     if (encryption.is(py::bool_(true))) {
@@ -464,14 +451,14 @@ void save_pdf(
     }
 
     if (!progress.is_none()) {
-        auto reporter = PointerHolder<QPDFWriter::ProgressReporter>(new PikeProgressReporter(progress));
+        auto reporter = PointerHolder<QPDFWriter::ProgressReporter>(
+            new PikeProgressReporter(progress));
         w.registerProgressReporter(reporter);
     }
 
     w.write();
 }
 
-
 void init_qpdf(py::module_ &m)
 {
     py::enum_<qpdf_object_stream_e>(m, "ObjectStreamMode")
@@ -498,40 +485,43 @@ void init_qpdf(py::module_ &m)
         .value("mmap", access_mode_e::access_mmap)
         .value("mmap_only", access_mode_e::access_mmap_only);
 
-    py::class_<QPDF, std::shared_ptr<QPDF>>(m, "Pdf", "In-memory representation of a PDF", py::dynamic_attr())
-        .def_static("new",
+    py::class_<QPDF, std::shared_ptr<QPDF>>(
+        m, "Pdf", "In-memory representation of a PDF", py::dynamic_attr())
+        .def_static(
+            "new",
             []() {
                 auto q = std::make_shared<QPDF>();
                 q->emptyPDF();
                 qpdf_basic_settings(*q);
                 return q;
             },
-            "Create a new empty PDF from stratch."
-        )
-        .def_static("_open", open_pdf, "",
+            "Create a new empty PDF from stratch.")
+        .def_static("_open",
+            open_pdf,
+            "",
             py::arg("filename_or_stream"),
-            py::arg("password") = "",
-            py::arg("hex_password") = false,
-            py::arg("ignore_xref_streams") = false,
-            py::arg("suppress_warnings") = true,
-            py::arg("attempt_recovery") = true,
+            py::arg("password")                = "",
+            py::arg("hex_password")            = false,
+            py::arg("ignore_xref_streams")     = false,
+            py::arg("suppress_warnings")       = true,
+            py::arg("attempt_recovery")        = true,
             py::arg("inherit_page_attributes") = true,
-            py::arg("access_mode") = access_mode_e::access_default
-        )
+            py::arg("access_mode")             = access_mode_e::access_default)
         .def("__repr__",
-            [](QPDF& q) {
-                return std::string("<pikepdf.Pdf description='") + q.getFilename() + std::string("'>");
-            }
-        )
-        .def_property_readonly("filename", &QPDF::getFilename,
+            [](QPDF &q) {
+                return std::string("<pikepdf.Pdf description='") + q.getFilename() +
+                       std::string("'>");
+            })
+        .def_property_readonly("filename",
+            &QPDF::getFilename,
             "The source filename of an existing PDF, when available.")
-        .def_property_readonly("pdf_version", &QPDF::getPDFVersion,
+        .def_property_readonly("pdf_version",
+            &QPDF::getPDFVersion,
             "The version of the PDF specification used for this file, such as '1.7'.")
         .def_property_readonly("extension_level", &QPDF::getExtensionLevel)
-        .def_property_readonly("Root", &QPDF::getRoot,
-            "The /Root object of the PDF."
-        )
-        .def_property_readonly("trailer", &QPDF::getTrailer,
+        .def_property_readonly("Root", &QPDF::getRoot, "The /Root object of the PDF.")
+        .def_property_readonly("trailer",
+            &QPDF::getTrailer,
             R"~~~(
             Provides access to the PDF trailer object.
 
@@ -539,43 +529,38 @@ void init_qpdf(py::module_ &m)
             the trailer should not be modified with pikepdf, and modifying it
             may not work. Some of the values in the trailer are automatically
             changed when a file is saved.
-            )~~~"
-        )
-        .def_property_readonly("pages",
-            [](std::shared_ptr<QPDF> q) {
-                return PageList(q);
-            },
+            )~~~")
+        .def_property_readonly(
+            "pages",
+            [](std::shared_ptr<QPDF> q) { return PageList(q); },
             R"~~~(
             Returns the list of pages.
 
             Return type:
                 pikepdf._qpdf.PageList
             )~~~",
-            py::return_value_policy::reference_internal
-        )
+            py::return_value_policy::reference_internal)
         .def_property_readonly("_pages", &QPDF::getAllPages)
-        .def_property_readonly("is_encrypted", &QPDF::isEncrypted,
+        .def_property_readonly("is_encrypted",
+            &QPDF::isEncrypted,
             R"~~~(
             Returns True if the PDF is encrypted.
 
             For information about the nature of the encryption, see
             :attr:`Pdf.encryption`.
-            )~~~"
-        )
-        .def_property_readonly("is_linearized", &QPDF::isLinearized,
+            )~~~")
+        .def_property_readonly("is_linearized",
+            &QPDF::isLinearized,
             R"~~~(
             Returns True if the PDF is linearized.
 
             Specifically returns True iff the file starts with a linearization
             parameter dictionary.  Does no additional validation.
-            )~~~"
-        )
-        .def("check_linearization",
-            [](QPDF& q, py::object stream) {
-                py::scoped_estream_redirect redirector(
-                    std::cerr,
-                    stream
-                );
+            )~~~")
+        .def(
+            "check_linearization",
+            [](QPDF &q, py::object stream) {
+                py::scoped_estream_redirect redirector(std::cerr, stream);
                 return q.checkLinearization();
             },
             R"~~~(
@@ -594,25 +579,26 @@ void init_qpdf(py::module_ &m)
             Raises:
                 RuntimeError: If the PDF in question is not linearized at all.
             )~~~",
-            py::arg_v("stream", py::module_::import("sys").attr("stderr"), "sys.stderr")
-        )
-        .def("get_warnings", // this is a def because it modifies state by clearing warnings
-            [](QPDF& q) {
+            py::arg_v(
+                "stream", py::module_::import("sys").attr("stderr"), "sys.stderr"))
+        .def("get_warnings", // this is a def because it modifies state by clearing
+                             // warnings
+            [](QPDF &q) {
                 py::list warnings;
-                for (auto w: q.getWarnings()) {
+                for (auto w : q.getWarnings()) {
                     warnings.append(w.what());
                 }
                 return warnings;
-            }
-        )
-        .def("show_xref_table", &QPDF::showXRefTable,
+            })
+        .def("show_xref_table",
+            &QPDF::showXRefTable,
             R"~~~(
             Pretty-print the Pdf's xref (cross-reference table)
             )~~~",
-            py::call_guard<py::scoped_ostream_redirect>()
-        )
-        .def("_add_page",
-            [](QPDF& q, QPDFObjectHandle& page, bool first=false) {
+            py::call_guard<py::scoped_ostream_redirect>())
+        .def(
+            "_add_page",
+            [](QPDF &q, QPDFObjectHandle &page, bool first = false) {
                 q.addPage(page, first);
             },
             R"~~~(
@@ -626,13 +612,13 @@ void init_qpdf(py::module_ &m)
                 first (bool): If True, prepend this before the first page; if False append after last page
             )~~~",
             py::arg("page"),
-            py::arg("first")=false,
-            py::keep_alive<1, 2>()
-        )
+            py::arg("first") = false,
+            py::keep_alive<1, 2>())
         .def("_add_page_at", &QPDF::addPageAt, py::keep_alive<1, 2>())
         .def("_remove_page", &QPDF::removePage)
-        .def("remove_unreferenced_resources",
-            [](QPDF& q) {
+        .def(
+            "remove_unreferenced_resources",
+            [](QPDF &q) {
                 QPDFPageDocumentHelper helper(q);
                 helper.removeUnreferencedResources();
             },
@@ -653,28 +639,29 @@ void init_qpdf(py::module_ &m)
 
             Suggested before saving, if content streams or /Resources dictionaries
             are edited.
-            )~~~"
-        )
-        .def("_save", save_pdf, "",
+            )~~~")
+        .def("_save",
+            save_pdf,
+            "",
             py::arg("filename"),
-            py::arg("static_id")=false,
-            py::arg("preserve_pdfa")=true,
-            py::arg("min_version")="",
-            py::arg("force_version")="",
-            py::arg("fix_metadata_version")=true,
-            py::arg("compress_streams")=true,
-            py::arg("stream_decode_level")=py::none(),
-            py::arg("object_stream_mode")=qpdf_object_stream_e::qpdf_o_preserve,
-            py::arg("normalize_content")=false,
-            py::arg("linearize")=false,
-            py::arg("qdf")=false,
-            py::arg("progress")=py::none(),
-            py::arg("encryption")=py::none(),
-            py::arg("samefile_check")=true,
-            py::arg("recompress_flate")=false
-        )
+            py::arg("static_id")            = false,
+            py::arg("preserve_pdfa")        = true,
+            py::arg("min_version")          = "",
+            py::arg("force_version")        = "",
+            py::arg("fix_metadata_version") = true,
+            py::arg("compress_streams")     = true,
+            py::arg("stream_decode_level")  = py::none(),
+            py::arg("object_stream_mode")   = qpdf_object_stream_e::qpdf_o_preserve,
+            py::arg("normalize_content")    = false,
+            py::arg("linearize")            = false,
+            py::arg("qdf")                  = false,
+            py::arg("progress")             = py::none(),
+            py::arg("encryption")           = py::none(),
+            py::arg("samefile_check")       = true,
+            py::arg("recompress_flate")     = false)
         .def("_get_object_id", &QPDF::getObjectByID)
-        .def("get_object",
+        .def(
+            "get_object",
             [](QPDF &q, std::pair<int, int> objgen) {
                 return q.getObjectByID(objgen.first, objgen.second);
             },
@@ -685,12 +672,10 @@ void init_qpdf(py::module_ &m)
                 pikepdf.Object
             )~~~",
             py::return_value_policy::reference_internal,
-            py::arg("objgen")
-        )
-        .def("get_object",
-            [](QPDF &q, int objid, int gen) {
-                return q.getObjectByID(objid, gen);
-            },
+            py::arg("objgen"))
+        .def(
+            "get_object",
+            [](QPDF &q, int objid, int gen) { return q.getObjectByID(objid, gen); },
             R"~~~(
             Look up an object by ID and generation number
 
@@ -699,12 +684,10 @@ void init_qpdf(py::module_ &m)
             )~~~",
             py::return_value_policy::reference_internal,
             py::arg("objid"),
-            py::arg("gen")
-        )
-        .def_property_readonly("objects",
-            [](QPDF &q) {
-                return q.getAllObjects();
-            },
+            py::arg("gen"))
+        .def_property_readonly(
+            "objects",
+            [](QPDF &q) { return q.getAllObjects(); },
             R"~~~(
             Return an iterable list of all objects in the PDF.
 
@@ -714,9 +697,9 @@ void init_qpdf(py::module_ &m)
             Retun type:
                 pikepdf._ObjectList
             )~~~",
-            py::return_value_policy::reference_internal
-        )
-        .def("make_indirect", &QPDF::makeIndirectObject,
+            py::return_value_policy::reference_internal)
+        .def("make_indirect",
+            &QPDF::makeIndirectObject,
             R"~~~(
             Attach an object to the Pdf as an indirect object
 
@@ -737,9 +720,9 @@ void init_qpdf(py::module_ &m)
             Return type:
                 pikepdf.Object
             )~~~",
-            py::arg("h")
-        )
-        .def("make_indirect",
+            py::arg("h"))
+        .def(
+            "make_indirect",
             [](QPDF &q, py::object obj) -> QPDFObjectHandle {
                 return q.makeIndirectObject(objecthandle_encode(obj));
             },
@@ -749,9 +732,9 @@ void init_qpdf(py::module_ &m)
             Return type:
                 pikepdf.Object
             )~~~",
-            py::arg("obj")
-        )
-        .def("copy_foreign",
+            py::arg("obj"))
+        .def(
+            "copy_foreign",
             [](QPDF &q, QPDFObjectHandle &h) -> QPDFObjectHandle {
                 return q.copyForeignObject(h);
             },
@@ -782,35 +765,28 @@ void init_qpdf(py::module_ &m)
             )~~~",
             py::return_value_policy::reference_internal,
             py::keep_alive<1, 2>(),
-            py::arg("h")
-        )
+            py::arg("h"))
         .def("_replace_object",
             [](QPDF &q, std::pair<int, int> objgen, QPDFObjectHandle &h) {
                 q.replaceObject(objgen.first, objgen.second, h);
-            }
-        )
+            })
         .def("_swap_objects",
             [](QPDF &q, std::pair<int, int> objgen1, std::pair<int, int> objgen2) {
                 QPDFObjGen o1(objgen1.first, objgen1.second);
                 QPDFObjGen o2(objgen2.first, objgen2.second);
                 q.swapObjects(o1, o2);
-            }
-        )
-        .def("_process",
+            })
+        .def(
+            "_process",
             [](QPDF &q, std::string description, py::bytes data) {
                 std::string s = data;
-                q.processMemoryFile(
-                    description.c_str(),
-                    s.data(),
-                    s.size()
-                );
+                q.processMemoryFile(description.c_str(), s.data(), s.size());
             },
             R"~~~(
             Process a new in-memory PDF, replacing the existing PDF
 
             Used to implement Pdf.close().
-            )~~~"
-        )
+            )~~~")
         .def("_decode_all_streams_and_discard",
             [](QPDF &q) {
                 QPDFWriter w(q);
@@ -818,98 +794,68 @@ void init_qpdf(py::module_ &m)
                 w.setOutputPipeline(&discard);
                 w.setDecodeLevel(qpdf_dl_all);
                 w.write();
-            }
-        )
-        .def_property_readonly("_allow_accessibility",
-            [](QPDF &q) {
-                return q.allowAccessibility();
-            }
-        )
-        .def_property_readonly("_allow_extract",
-            [](QPDF &q) {
-                return q.allowExtractAll();
-            }
-        )
-        .def_property_readonly("_allow_print_lowres",
-            [](QPDF &q) {
-                return q.allowPrintLowRes();
-            }
-        )
-        .def_property_readonly("_allow_print_highres",
-            [](QPDF &q) {
-                return q.allowPrintHighRes();
-            }
-        )
-        .def_property_readonly("_allow_modify_assembly",
-            [](QPDF &q) {
-                return q.allowModifyAssembly();
-            }
-        )
-        .def_property_readonly("_allow_modify_form",
-            [](QPDF &q) {
-                return q.allowModifyForm();
-            }
-        )
+            })
+        .def_property_readonly(
+            "_allow_accessibility", [](QPDF &q) { return q.allowAccessibility(); })
+        .def_property_readonly(
+            "_allow_extract", [](QPDF &q) { return q.allowExtractAll(); })
+        .def_property_readonly(
+            "_allow_print_lowres", [](QPDF &q) { return q.allowPrintLowRes(); })
+        .def_property_readonly(
+            "_allow_print_highres", [](QPDF &q) { return q.allowPrintHighRes(); })
+        .def_property_readonly(
+            "_allow_modify_assembly", [](QPDF &q) { return q.allowModifyAssembly(); })
+        .def_property_readonly(
+            "_allow_modify_form", [](QPDF &q) { return q.allowModifyForm(); })
         .def_property_readonly("_allow_modify_annotation",
-            [](QPDF &q) {
-                return q.allowModifyAnnotation();
-            }
-        )
-        .def_property_readonly("_allow_modify_other",
-            [](QPDF &q) {
-                return q.allowModifyOther();
-            }
-        )
-        .def_property_readonly("_allow_modify_all",
-            [](QPDF &q) {
-                return q.allowModifyAll();
-            }
-        )
+            [](QPDF &q) { return q.allowModifyAnnotation(); })
+        .def_property_readonly(
+            "_allow_modify_other", [](QPDF &q) { return q.allowModifyOther(); })
+        .def_property_readonly(
+            "_allow_modify_all", [](QPDF &q) { return q.allowModifyAll(); })
         .def_property_readonly("_encryption_data",
             [](QPDF &q) {
-                int R = 0;
-                int P = 0;
-                int V = 0;
+                int R                                   = 0;
+                int P                                   = 0;
+                int V                                   = 0;
                 QPDF::encryption_method_e stream_method = QPDF::e_unknown;
                 QPDF::encryption_method_e string_method = QPDF::e_unknown;
-                QPDF::encryption_method_e file_method = QPDF::e_unknown;
+                QPDF::encryption_method_e file_method   = QPDF::e_unknown;
                 if (!q.isEncrypted(R, P, V, stream_method, string_method, file_method))
                     return py::dict();
 
-                auto user_passwd = q.getTrimmedUserPassword();
+                auto user_passwd    = q.getTrimmedUserPassword();
                 auto encryption_key = q.getEncryptionKey();
 
-                return py::dict(
-                    py::arg("R") = R,
-                    py::arg("P") = P,
-                    py::arg("V") = V,
-                    py::arg("stream") = stream_method,
-                    py::arg("string") = string_method,
-                    py::arg("file") = file_method,
-                    py::arg("user_passwd") = py::bytes(user_passwd),
-                    py::arg("encryption_key") = py::bytes(encryption_key)
-                );
-            }
-        )
-        .def_property_readonly("user_password_matched", &QPDF::userPasswordMatched,
+                return py::dict(py::arg("R")  = R,
+                    py::arg("P")              = P,
+                    py::arg("V")              = V,
+                    py::arg("stream")         = stream_method,
+                    py::arg("string")         = string_method,
+                    py::arg("file")           = file_method,
+                    py::arg("user_passwd")    = py::bytes(user_passwd),
+                    py::arg("encryption_key") = py::bytes(encryption_key));
+            })
+        .def_property_readonly("user_password_matched",
+            &QPDF::userPasswordMatched,
             R"~~~(
             Returns True if the user password matched when the ``Pdf`` was opened.
 
             It is possible for both the user and owner passwords to match.
 
             .. versionadded:: 2.10
-            )~~~"
-        )
-        .def_property_readonly("owner_password_matched", &QPDF::ownerPasswordMatched,
+            )~~~")
+        .def_property_readonly("owner_password_matched",
+            &QPDF::ownerPasswordMatched,
             R"~~~(
             Returns True if the owner password matched when the ``Pdf`` was opened.
 
             It is possible for both the user and owner passwords to match.
 
             .. versionadded:: 2.10
-            )~~~"
-        )
-        .def("generate_appearance_streams",
+            )~~~")
+        .def(
+            "generate_appearance_streams",
             [](QPDF &q) {
                 QPDFAcroFormDocumentHelper afdh(q);
                 afdh.generateAppearancesIfNeeded();
@@ -935,12 +881,12 @@ void init_qpdf(py::module_ &m)
                 https://github.com/qpdf/qpdf/blob/bf6b9ba1c681a6fac6d585c6262fb2778d4bb9d2/include/qpdf/QPDFFormFieldObjectHelper.hh#L216
 
             .. versionadded:: 2.11
-            )~~~"
-        )
-        .def("flatten_annotations",
+            )~~~")
+        .def(
+            "flatten_annotations",
             [](QPDF &q, std::string mode) {
                 QPDFPageDocumentHelper dh(q);
-                auto required = 0;
+                auto required  = 0;
                 auto forbidden = an_invisible | an_hidden;
 
                 if (mode == "screen") {
@@ -950,7 +896,8 @@ void init_qpdf(py::module_ &m)
                 } else if (mode == "" || mode == "all") {
                     // No op
                 } else {
-                    throw py::value_error("Mode must be one of 'all', 'screen', 'print'.");
+                    throw py::value_error(
+                        "Mode must be one of 'all', 'screen', 'print'.");
                 }
 
                 dh.flattenAnnotations(required, forbidden);
@@ -976,7 +923,5 @@ void init_qpdf(py::module_ &m)
 
             .. versionadded:: 2.11
             )~~~",
-            py::arg("mode") = "all"
-        )
-        ; // class Pdf
+            py::arg("mode") = "all"); // class Pdf
 }
