@@ -3,6 +3,7 @@ Testing focused on pikepdf.Pdf
 """
 
 import locale
+import os
 import shutil
 import sys
 import zlib
@@ -325,7 +326,7 @@ def test_recompress(resources, outdir):
         assert smaller.stat().st_size < bigger.stat().st_size
 
 
-def test_flate_compression_level():
+def test_invalid_flate_compression_level():
     # We don't want to change the compression level because it's global state
     # and will change subsequent test results, so just ping it with an invalid
     # value to get partial code coverage.
@@ -333,6 +334,14 @@ def test_flate_compression_level():
         pikepdf._qpdf.set_flate_compression_level(99)
 
 
+if os.name == 'posix':
+    # Can't even let non-POSIX platforms see this marker e.g. by using .mark.skipif
+    # or they will fail on a pytest internalerror.
+    @pytest.mark.forked
+    def test_flate_compression_level():
+        pikepdf._qpdf.set_flate_compression_level(1)
+
+
 def test_generate_appearance_streams(pdf_form):
     assert Name.AP not in pdf_form.Root.AcroForm.Fields[0]
 
